# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class EticStockMove(models.Model):
    _inherit = "stock.move"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    product_uom_relative_qty_draft = fields.Float(
        string="Quantité demandée",
        compute="_compute_product_uom_relative_qty",
        store=True,
    )
    product_uom_relative_qty_done = fields.Float(
        string="Quantité réelle",
        compute="_compute_product_uom_relative_qty",
        store=True,
    )
    amount_consigne_relative = fields.Float(
        string="Solde", compute="_compute_amount_consigne_relative", store=True
    )

    # ------------------------------------------------------
    # Compute
    # ------------------------------------------------------
    @api.depends(
        "picking_code", "product_uom_qty", "state", "product_uom_relative_qty_draft"
    )
    def _compute_product_uom_relative_qty(self):
        """
        If move_stock is leaving partner -> Qty * -1
        """
        for r in self:
            if r.picking_code == "outgoing":
                r.product_uom_relative_qty_draft = r.product_uom_qty
            elif r.picking_code == "incoming":
                r.product_uom_relative_qty_draft = -1 * r.product_uom_qty
            else:
                r.product_uom_relative_qty_draft = 0

            if r.state == "done":
                r.product_uom_relative_qty_done = r.product_uom_relative_qty_draft
            else:
                r.product_uom_relative_qty_done = 0

    @api.depends("product_id.standard_price", "product_uom_relative_qty_done")
    def _compute_amount_consigne_relative(self):
        for r in self:
            r.amount_consigne_relative = (
                r.product_id.standard_price * r.product_uom_relative_qty_done
            )

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------
    def action_open_stock_move(self):
        return {
            "type": "ir.actions.act_window",
            "name": "Opération",
            "views": [[False, "form"]],
            "view_type": "form",
            "res_model": "stock.picking",
            "target": "current",
            "res_id": self.picking_id.id,
        }
